type LoadResults<LoadResult = any> = Record<string, LoadResult>;
export type SeamOptions = {
    rootDirectory: string;
};
export declare class Seam {
    private static readonly PACKAGE_JSON_FILE;
    private static readonly NODE_MODULES_DIRECTORY;
    private static readonly ON_LOAD_CALLBACK_NAME;
    private static readonly ON_UNLOAD_CALLBACK_NAME;
    private _rootDirectory;
    private _pluginsInstallationNodeModulesDirectory;
    private readonly _pluginRegister;
    private readonly _specifierMap;
    private readonly _loaded;
    private readonly _reloading;
    private _installationFlags;
    constructor(options: SeamOptions);
    loadPlugins(...names: string[]): Promise<LoadResults>;
    unloadPlugin(name: string): Promise<void>;
    unloadPlugins(...names: string[]): Promise<void>;
    reloadPlugin(name: string, reinstall?: boolean): Promise<void>;
    registerPlugins(...names: string[]): Promise<void>;
    unregisterPlugin(name: string): Promise<void>;
    unregisterPlugins(...names: string[]): Promise<void>;
    /**
     * Installs a list of plugin specifiers to the internal plugin store.
     *
     * @param specifiers An array of NPM specifiers for plugins to install.
     */
    installPlugins(...specifiers: string[]): Promise<any[]>;
    _resolveRelativeFileDependencies(packageJsonPath: string, relativeTo: string): Promise<void>;
    /**
     * Uninstalls a plugin from the internal plugin store.
     * @param name The name of the plugin to uninstall.
     */
    uninstallPlugin(name: string): Promise<void>;
    uninstallPlugins(...names: string[]): Promise<void>;
    uninstallAllPlugins(): Promise<void>;
    isPluginLoaded(name: string): boolean;
    isPluginRegistered(name: string): boolean;
    isPluginInstalled(name: string): Promise<boolean>;
    getLoadedPlugins(): string[];
    getRegisteredPlugins(): string[];
    private _getNormalizedPluginSpecifiers;
    getPluginInstallationDirectory(name: string): string;
    getPluginPackageJsonPath(name: string): string;
    getPluginPackageJson(name: string): Promise<{
        name: string;
        files: string[];
        exports: import("@lucania/schema").DynamicObjectModel<import("@lucania/schema").OrSetSchema<[import("@lucania/schema").StringSchema<true, undefined>, import("@lucania/schema").ObjectSchema<{
            node: import("@lucania/schema").StringSchema<false, undefined>;
            default: import("@lucania/schema").StringSchema<false, undefined>;
        }, true, undefined>], true, undefined>>;
        dependencies: import("@lucania/schema").DynamicObjectModel<import("@lucania/schema").StringSchema<true, undefined>>;
        config: any;
    } & {
        type?: string | undefined;
        main?: string | undefined;
    }>;
    getPackageJsonPath(): string;
    getPackageJson(): Promise<{
        name: string;
        files: string[];
        exports: import("@lucania/schema").DynamicObjectModel<import("@lucania/schema").OrSetSchema<[import("@lucania/schema").StringSchema<true, undefined>, import("@lucania/schema").ObjectSchema<{
            node: import("@lucania/schema").StringSchema<false, undefined>;
            default: import("@lucania/schema").StringSchema<false, undefined>;
        }, true, undefined>], true, undefined>>;
        dependencies: import("@lucania/schema").DynamicObjectModel<import("@lucania/schema").StringSchema<true, undefined>>;
        config: any;
    } & {
        type?: string | undefined;
        main?: string | undefined;
    }>;
    getNodeModulesDirectory(): string;
    isPackageJsonExistent(): Promise<boolean>;
    getPluginInstallationModuleDirectory(name: string): string;
    private _generatePackageJson;
    private _findPluginName;
}
export {};
